@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..1\n"; }
+BEGIN { $| = 1; print "1..2\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use Netscape::Bookmarks;
 $loaded = 1;
@@ -18,3 +18,16 @@ print "ok 1\n";
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
 
+eval {
+my $netscape = Netscape::Bookmarks->new( "bookmark_files/Bookmarks.html" );
+
+open FILE, "> bookmark_files/Bookmarks_tmp.html" or die "Could not open tmp file: $!";
+print FILE $netscape->as_string;
+close FILE;
+};
+
+print STDERR $@ if $@;
+
+print $@ ? 'not ' : '', 'ok 2', "\n";
+
+END { unlink "bookmark_files/Bookmarks_tmp.html" }
